Crate kcr_applicationautoscaling_services_k8s_aws

Crate kcr_applicationautoscaling_services_k8s_aws 

This crate contains kube-rs compatible bindings for Kubernetes custom resources for the applicationautoscaling.services.k8s.aws group. Each binding is generated with kopium, updated and released weekly.

Available Custom Resources

applicationautoscaling.services.k8s.aws/v1alpha1

  • ScalableTarget
  • ScalingPolicy

Modules

v1alpha1